==> mythdvd_0.16.orig.tar.gz: mythdvd-0.16/i18n/mythdvd_ja.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>DVDRipBox</name>
    <message>
        <source>Your connection to the Myth Transcoding Daemon has gone away. This is not a good thing.</source>
        <translation>トランスコーディングデーモンとの接続が終了しました｡問題が発生しているようです｡</translation>
    </message>
    <message>
        <source>Cannot connect to your Myth Transcoding Daemon. You can try hitting any number key to start it. If you still see this message, then something is really wrong.</source>
        <translation>トランスコーディングデーモンに接続できませんでした｡数字キーを押すと再接続します｡もしこのメッセージが表示されている場合は問題が発生しています｡</translation>
    </message>
    <message>
        <source>Attempting to connect to your mtd said host not found. This is unrecoverably bad. </source>
        <translation>トランスコーディングデーモンが接続するホストが見つかりません｡回復できません｡</translation>
    </message>
    <message>
        <source>Socket communication errors. This is unrecoverably bad. </source>
        <translation>ソケットコミュニケーションエラー。回復できません｡</translation>
    </message>
    <message>
        <source>Something is wrong, but I don&apos;t know what.</source>
        <translation>不明な問題が発生しました｡</translation>
    </message>
    <message>
        <source>Job %1 of %2</source>
        <translation>ジョブ %1 of %2</translation>
    </message>
    <message>
        <source>No jobs and nothing else to do. You could hit 0 to rip a DVD.</source>
        <translation>ジョブがありません｡&quot;0&quot;キーを押すとDVDをリッピングします｡</translation>
    </message>
    <message>
        <source>No Jobs. Checking and/or waiting for DVD.</source>
        <translation>ジョブなし。DVDの検査及びDVD待ちです｡</translation>
    </message>
    <message>
        <source>No jobs and nothing else to do. You could hit 0 to rip a disc if you like.</source>
        <translation>ジョブなし｡&quot;0&quot;キーを押すとリッピングします｡</translation>
    </message>
    <message>
        <source>Cancelling ...</source>
        <translation>キャンセル中・・・</translation>
    </message>
    <message>
        <source>0 New Rip</source>
        <translation>0 新規リッピング</translation>
    </message>
    <message>
        <source>9 Cancel Job</source>
        <translation>9 キャンセルジョブ</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>

You have no VCD Player command defined.</source>
        <translation>

VCDプレイヤーコマンドが設定されていません｡</translation>
    </message>
    <message>
        <source>OK, I&apos;ll go run Setup</source>
        <translation>はい、セットアップを実行します｡</translation>
    </message>
    <message>
        <source>

You have no VCD Device defined.</source>
        <translation>

VCDデバイスが設定されていません｡</translation>
    </message>
    <message>
        <source>

You have no DVD Player command defined.</source>
        <translation>

DVDプレイヤーのコマンドが設定されていません｡</translation>
    </message>
    <message>
        <source>

You have no DVD Device defined.</source>
        <translation>

DVDデバイスが設定されていません｡</translation>
    </message>
    <message>
        <source>Location of VCD device</source>
        <translation>VCDデバイスの場所</translation>
    </message>
    <message>
        <source>This device must exist, and the user running MythDVD needs to have read permission on the device.</source>
        <translation>このデバイスは必ず存在しなければなりません｡そしてMythDVDの実行ユーザーが読める権限が必要です｡</translation>
    </message>
    <message>
        <source>Location of DVD device</source>
        <translation>DVDデバイスの場所</translation>
    </message>
    <message>
        <source>General Settings</source>
        <translation>全般設定</translation>
    </message>
    <message>
        <source>DVD Player Command</source>
        <translation>DVDプレイヤーコマンド</translation>
    </message>
    <message>
        <source>This can be any command to launch a DVD player (e.g. MPlayer, ogle, etc.). If present, %d will be substituted for the DVD device (e.g. /dev/dvd).</source>
        <translation>DVDプレイヤーを起動するコマンドが可能です(例 MPlayer, ogle, etc.)。&quot;%d&quot;がDVDデバイスの代用になります(例 /dev/dvd)｡</translation>
    </message>
    <message>
        <source>VCD Player Command</source>
        <translation>VCDプレイヤーコマンド</translation>
    </message>
    <message>
        <source>This can be any command to launch a VCD player (e.g. MPlayer, xine, etc.). If present, %d will be substituted for the VCD device (e.g. /dev/cdrom).</source>
        <translation>VCDプレイヤーを起動するコマンドが可能です(例 MPlayer, xine, etc.)｡&quot;%d&quot;がVCDデバイスの代用になります(例 /dev/cdrom)｡</translation>
    </message>
    <message>
        <source>DVD Player Settings</source>
        <translation>DVDプレイヤー設定</translation>
    </message>
    <message>
        <source>VCD Player Settings</source>
        <translation>VCDプレイヤー設定</translation>
    </message>
    <message>
        <source>Directory to hold temporary files</source>
        <translation>一時ファイルディレクトリ</translation>
    </message>
    <message>
        <source>This directory must exist, and the user running MythDVD needs to have write permission to the directory.</source>
        <translation>このディレクトリは必ず存在しなければなりません｡そしてMythDVDを実行するユーザーが書き込み権限が必要です｡</translation>
    </message>
    <message>
        <source>Title Playing Command</source>
        <translation>タイトル再生コマンド</translation>
    </message>
    <message>
        <source>This is a command used to preview a given title on a DVD. If present %t will be set to the title, %d for device, %a for audio track, %c for audio channels.</source>
        <translation>DVDのタイトル再生に使用します｡&quot;%t&quot;がタイトル、&quot;%d&quot;がデバイス、&quot;%a&quot;がオーディオトラック、&quot;%c&quot;がオーディオチャンネルの代用になります｡</translation>
    </message>
    <message>
        <source>Subtitle arguments:</source>
        <translation>サブタイトル引数:</translation>
    </message>
    <message>
        <source>If you choose any subtitles for ripping, this command is added to the end of the Title Play Command to allow previewing of subtitles. If  present %s will be set to the subtitle track. </source>
        <translation>サブタイトルを選択してリッピングするときにこのコマンドをタイトル再生コマンドの後に続けてサブタイトルを再生します｡&quot;%s&quot;がサブタイトルトラックの代用になります｡</translation>
    </message>
    <message>
        <source>Base transcode command</source>
        <translation>ベーストランスコードコマンド</translation>
    </message>
    <message>
        <source>This is the base (without arguments) command to run transcode on your system.</source>
        <translation>あなたのシステムの基本のトランスコードコマンドです｡(引数なし)。</translation>
    </message>
    <message>
        <source>MTD port number</source>
        <translation>MTDポート番号</translation>
    </message>
    <message>
        <source>The port number that should be used for communicating with the MTD (Myth Transcoding Daemon)</source>
        <translation>MTD(Myth トランスコーディングデーモン)と接続するときに使うポート番号</translation>
    </message>
    <message>
        <source>MTD logs to terminal window</source>
        <translation>MTDログをターミナルウィンドウに出力する｡</translation>
    </message>
    <message>
        <source>If set, the MTD (Myth Transcoding Daemon) will log to the window it is started from. Otherwise, it will write to a file called  mtd.log in the top level ripping directory.</source>
        <translation>これを設定するとMTD(Myth トランスコーディングデーモン)は開始されたウィンドウにログを出力します｡その他はリッピング、トップレベルのディレクトリにmtd.logファイルの名称で書き込みます｡</translation>
    </message>
    <message>
        <source>Transcode AC3 Audio</source>
        <translation>AC3オーディオに変換する</translation>
    </message>
    <message>
        <source>If set, the MTD (Myth Transcoding Daemon) will, by default, preserve AC3 (Dolby Digital) audio in transcoded files. </source>
        <translation>MTD(Myth トランスコーディングデーモン)がファイルに保存するときにAC3(Dolby Digital)オーディオに変換します｡</translation>
    </message>
    <message>
        <source>Use xvid rather than divx</source>
        <translation>divxの変わりにxvidを使用する</translation>
    </message>
    <message>
        <source>If set, mythdvd will use the (open, free) xvid codec rather than divx whenever possible.</source>
        <translation>これを設定するとmythdvdは(オープン、フリー)xvidコーデックが使用可能なときはdivxの変わりに使用します｡</translation>
    </message>
    <message>
        <source>Nice level for MTD</source>
        <translation>MTDのNiceレベル</translation>
    </message>
    <message>
        <source>This determines the priority of the Myth Transcoding Daemon. Higher numbers mean lower priority (more CPU to other tasks).</source>
        <translation>Mythトランスコーディグデーモンの優先順位を設定します｡大きい数字が優先順位が低いです｡</translation>
    </message>
    <message>
        <source>Ripped video segments</source>
        <translation></translation>
    </message>
    <message>
        <source>If set to something other than 0, ripped video titles will be broken up into files of this size (in MB). Applies to both perfect quality recordings and intermediate files used for transcoding.</source>
        <translation></translation>
    </message>
    <message>
        <source>DVD Ripper Settings</source>
        <translation>DVDリッパー設定</translation>
    </message>
    <message>
        <source>MTD Settings</source>
        <translation>MTD設定&gt;</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>不明</translation>
    </message>
    <message>
        <source>Waiting For Access to DVD</source>
        <translation>DVDアクセス待ち</translation>
    </message>
    <message>
        <source>Ripping to file ~</source>
        <translation>リッピング中 ファイル ~</translation>
    </message>
    <message>
        <source>Perfect DVD Rip of %1</source>
        <translation>完璧DVDリッピング %1</translation>
    </message>
    <message>
        <source>Transcode of %1</source>
        <translation>変換 %1</translation>
    </message>
    <message>
        <source>Waiting for Permission to Start Transcoding</source>
        <translation>変換開始を待ってます</translation>
    </message>
    <message>
        <source>Transcoding Pass 1 of 2 ~</source>
        <translation>変換パス 1 of 2 ~</translation>
    </message>
    <message>
        <source>Transcoding Pass 2 of 2 ~</source>
        <translation>変換パス 2 of 2 ~</translation>
    </message>
    <message>
        <source>Transcoding ~</source>
        <translation>変換中 ~</translation>
    </message>
    <message>
        <source>Transcode is thinking </source>
        <translation></translation>
    </message>
    <message>
        <source>Simultaneous Transcode Jobs</source>
        <translation>同時変換ジョブ</translation>
    </message>
    <message>
        <source>This determines the number of simultaneous transcode jobs. If set at 1 (the default), there will only be one active job at a time.</source>
        <translation>同時に変換するジョブ数を設定します｡1に設定すると(既定)一度に一つ処理します｡</translation>
    </message>
</context>
<context>
    <name>ThemeUI</name>
    <message>
        <source>Rip/Transcode</source>
        <translation>リッピング/変換</translation>
    </message>
    <message>
        <source>Job 1 of 1</source>
        <translation>ジョブ 1/1</translation>
    </message>
    <message>
        <source>Length:</source>
        <translation>長さ:</translation>
    </message>
    <message>
        <source>Select:</source>
        <translation>選択:</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>名前:</translation>
    </message>
    <message>
        <source>Quality:</source>
        <translation>品質:</translation>
    </message>
    <message>
        <source>Audio Track:</source>
        <translation>オーディオトラック:</translation>
    </message>
    <message>
        <source>AC3 Audio:</source>
        <translation>AC3オーディオ:</translation>
    </message>
    <message>
        <source>Subtitles:</source>
        <translation>サブタイトル:</translation>
    </message>
    <message>
        <source>View:</source>
        <translation>ビュー:</translation>
    </message>
    <message>
        <source>Title 1 of 1</source>
        <translation>タイトル 1/1</translation>
    </message>
    <message>
        <source>0:00:00</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TitleDialog</name>
    <message>
        <source>Unkown</source>
        <translation>不明</translation>
    </message>
    <message>
        <source>%1 - Title %2</source>
        <translation>%1 - タイトル %2</translation>
    </message>
    <message>
        <source>Perfect</source>
        <translation>完璧</translation>
    </message>
    <message>
        <source>None</source>
        <translation>無し</translation>
    </message>
    <message>
        <source>Title %1 of %2</source>
        <translation>タイトル %1 of %2</translation>
    </message>
    <message>
        <source>0 Process Selected Title</source>
        <translation>0 プロセス、選択タイトル</translation>
    </message>
    <message>
        <source>0 Process Selected Titles</source>
        <translation>0 プロセス、選択タイトル</translation>
    </message>
</context>
</TS>

==> mythdvd_0.17.orig.tar.gz: mythdvd-0.17/i18n/mythdvd_ja.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>DVDRipBox</name>
    <message>
        <source>Your connection to the Myth Transcoding Daemon has gone away. This is not a good thing.</source>
        <translation>トランスコーディングデーモンとの接続が終了しました｡問題が発生しているようです｡</translation>
    </message>
    <message>
        <source>Cannot connect to your Myth Transcoding Daemon. You can try hitting any number key to start it. If you still see this message, then something is really wrong.</source>
        <translation>トランスコーディングデーモンに接続できませんでした｡数字キーを押すと再接続します｡もしこのメッセージが表示されている場合は問題が発生しています｡</translation>
    </message>
    <message>
        <source>Attempting to connect to your mtd said host not found. This is unrecoverably bad. </source>
        <translation>トランスコーディングデーモンが接続するホストが見つかりません｡回復できません｡</translation>
    </message>
    <message>
        <source>Socket communication errors. This is unrecoverably bad. </source>
        <translation>ソケットコミュニケーションエラー。回復できません｡</translation>
    </message>
    <message>
        <source>Something is wrong, but I don&apos;t know what.</source>
        <translation>不明な問題が発生しました｡</translation>
    </message>
    <message>
        <source>Job %1 of %2</source>
        <translation>ジョブ %1 of %2</translation>
    </message>
    <message>
        <source>No jobs and nothing else to do. You could hit 0 to rip a DVD.</source>
        <translation>ジョブがありません｡&quot;0&quot;キーを押すとDVDをリッピングします｡</translation>
    </message>
    <message>
        <source>No Jobs. Checking and/or waiting for DVD.</source>
        <translation>ジョブなし。DVDの検査及びDVD待ちです｡</translation>
    </message>
    <message>
        <source>No jobs and nothing else to do. You could hit 0 to rip a disc if you like.</source>
        <translation>ジョブなし｡&quot;0&quot;キーを押すとリッピングします｡</translation>
    </message>
    <message>
        <source>Cancelling ...</source>
        <translation>キャンセル中・・・</translation>
    </message>
    <message>
        <source>0 New Rip</source>
        <translation>0 新規リッピング</translation>
    </message>
    <message>
        <source>9 Cancel Job</source>
        <translation>9 キャンセルジョブ</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>

You have no VCD Player command defined.</source>
        <translation>

VCDプレイヤーコマンドが設定されていません｡</translation>
    </message>
    <message>
        <source>OK, I&apos;ll go run Setup</source>
        <translation>はい、セットアップを実行します｡</translation>
    </message>
    <message>
        <source>

You have no VCD Device defined.</source>
        <translation>

VCDデバイスが設定されていません｡</translation>
    </message>
    <message>
        <source>

You have no DVD Player command defined.</source>
        <translation>

DVDプレイヤーのコマンドが設定されていません｡</translation>
    </message>
    <message>
        <source>

You have no DVD Device defined.</source>
        <translation>

DVDデバイスが設定されていません｡</translation>
    </message>
    <message>
        <source>Location of VCD device</source>
        <translation>VCDデバイスの場所</translation>
    </message>
    <message>
        <source>This device must exist, and the user running MythDVD needs to have read permission on the device.</source>
        <translation>このデバイスは必ず存在しなければなりません｡そしてMythDVDの実行ユーザーが読める権限が必要です｡</translation>
    </message>
    <message>
        <source>Location of DVD device</source>
        <translation>DVDデバイスの場所</translation>
    </message>
    <message>
        <source>General Settings</source>
        <translation>全般設定</translation>
    </message>
    <message>
        <source>DVD Player Command</source>
        <translation>DVDプレイヤーコマンド</translation>
    </message>
    <message>
        <source>This can be any command to launch a DVD player (e.g. MPlayer, ogle, etc.). If present, %d will be substituted for the DVD device (e.g. /dev/dvd).</source>
        <translation>DVDプレイヤーを起動するコマンドが可能です(例 MPlayer, ogle, etc.)。&quot;%d&quot;がDVDデバイスの代用になります(例 /dev/dvd)｡</translation>
    </message>
    <message>
        <source>VCD Player Command</source>
        <translation>VCDプレイヤーコマンド</translation>
    </message>
    <message>
        <source>This can be any command to launch a VCD player (e.g. MPlayer, xine, etc.). If present, %d will be substituted for the VCD device (e.g. /dev/cdrom).</source>
        <translation>VCDプレイヤーを起動するコマンドが可能です(例 MPlayer, xine, etc.)｡&quot;%d&quot;がVCDデバイスの代用になります(例 /dev/cdrom)｡</translation>
    </message>
    <message>
        <source>DVD Player Settings</source>
        <translation>DVDプレイヤー設定</translation>
    </message>
    <message>
        <source>VCD Player Settings</source>
        <translation>VCDプレイヤー設定</translation>
    </message>
    <message>
        <source>Directory to hold temporary files</source>
        <translation>一時ファイルディレクトリ</translation>
    </message>
    <message>
        <source>This directory must exist, and the user running MythDVD needs to have write permission to the directory.</source>
        <translation>このディレクトリは必ず存在しなければなりません｡そしてMythDVDを実行するユーザーが書き込み権限が必要です｡</translation>
    </message>
    <message>
        <source>Title Playing Command</source>
        <translation>タイトル再生コマンド</translation>
    </message>
    <message>
        <source>This is a command used to preview a given title on a DVD. If present %t will be set to the title, %d for device, %a for audio track, %c for audio channels.</source>
        <translation>DVDのタイトル再生に使用します｡&quot;%t&quot;がタイトル、&quot;%d&quot;がデバイス、&quot;%a&quot;がオーディオトラック、&quot;%c&quot;がオーディオチャンネルの代用になります｡</translation>
    </message>
    <message>
        <source>Subtitle arguments:</source>
        <translation>サブタイトル引数:</translation>
    </message>
    <message>
        <source>If you choose any subtitles for ripping, this command is added to the end of the Title Play Command to allow previewing of subtitles. If  present %s will be set to the subtitle track. </source>
        <translation>サブタイトルを選択してリッピングするときにこのコマンドをタイトル再生コマンドの後に続けてサブタイトルを再生します｡&quot;%s&quot;がサブタイトルトラックの代用になります｡</translation>
    </message>
    <message>
        <source>Base transcode command</source>
        <translation>ベーストランスコードコマンド</translation>
    </message>
    <message>
        <source>This is the base (without arguments) command to run transcode on your system.</source>
        <translation>あなたのシステムの基本のトランスコードコマンドです｡(引数なし)。</translation>
    </message>
    <message>
        <source>MTD port number</source>
        <translation>MTDポート番号</translation>
    </message>
    <message>
        <source>The port number that should be used for communicating with the MTD (Myth Transcoding Daemon)</source>
        <translation>MTD(Myth トランスコーディングデーモン)と接続するときに使うポート番号</translation>
    </message>
    <message>
        <source>MTD logs to terminal window</source>
        <translation>MTDログをターミナルウィンドウに出力する｡</translation>
    </message>
    <message>
        <source>If set, the MTD (Myth Transcoding Daemon) will log to the window it is started from. Otherwise, it will write to a file called  mtd.log in the top level ripping directory.</source>
        <translation>これを設定するとMTD(Myth トランスコーディングデーモン)は開始されたウィンドウにログを出力します｡その他はリッピング、トップレベルのディレクトリにmtd.logファイルの名称で書き込みます｡</translation>
    </message>
    <message>
        <source>Transcode AC3 Audio</source>
        <translation>AC3オーディオに変換する</translation>
    </message>
    <message>
        <source>If set, the MTD (Myth Transcoding Daemon) will, by default, preserve AC3 (Dolby Digital) audio in transcoded files. </source>
        <translation>MTD(Myth トランスコーディングデーモン)がファイルに保存するときにAC3(Dolby Digital)オーディオに変換します｡</translation>
    </message>
    <message>
        <source>Use xvid rather than divx</source>
        <translation>divxの変わりにxvidを使用する</translation>
    </message>
    <message>
        <source>If set, mythdvd will use the (open, free) xvid codec rather than divx whenever possible.</source>
        <translation>これを設定するとmythdvdは(オープン、フリー)xvidコーデックが使用可能なときはdivxの変わりに使用します｡</translation>
    </message>
    <message>
        <source>Nice level for MTD</source>
        <translation>MTDのNiceレベル</translation>
    </message>
    <message>
        <source>This determines the priority of the Myth Transcoding Daemon. Higher numbers mean lower priority (more CPU to other tasks).</source>
        <translation>Mythトランスコーディグデーモンの優先順位を設定します｡大きい数字が優先順位が低いです｡</translation>
    </message>
    <message>
        <source>Ripped video segments</source>
        <translation></translation>
    </message>
    <message>
        <source>If set to something other than 0, ripped video titles will be broken up into files of this size (in MB). Applies to both perfect quality recordings and intermediate files used for transcoding.</source>
        <translation></translation>
    </message>
    <message>
        <source>DVD Ripper Settings</source>
        <translation>DVDリッパー設定</translation>
    </message>
    <message>
        <source>MTD Settings</source>
        <translation>MTD設定&gt;</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>不明</translation>
    </message>
    <message>
        <source>Waiting For Access to DVD</source>
        <translation>DVDアクセス待ち</translation>
    </message>
    <message>
        <source>Ripping to file ~</source>
        <translation>リッピング中 ファイル ~</translation>
    </message>
    <message>
        <source>Perfect DVD Rip of %1</source>
        <translation>完璧DVDリッピング %1</translation>
    </message>
    <message>
        <source>Transcode of %1</source>
        <translation>変換 %1</translation>
    </message>
    <message>
        <source>Waiting for Permission to Start Transcoding</source>
        <translation>変換開始を待ってます</translation>
    </message>
    <message>
        <source>Transcoding Pass 1 of 2 ~</source>
        <translation>変換パス 1 of 2 ~</translation>
    </message>
    <message>
        <source>Transcoding Pass 2 of 2 ~</source>
        <translation>変換パス 2 of 2 ~</translation>
    </message>
    <message>
        <source>Transcoding ~</source>
        <translation>変換中 ~</translation>
    </message>
    <message>
        <source>Transcode is thinking </source>
        <translation></translation>
    </message>
    <message>
        <source>Simultaneous Transcode Jobs</source>
        <translation>同時変換ジョブ</translation>
    </message>
    <message>
        <source>This determines the number of simultaneous transcode jobs. If set at 1 (the default), there will only be one active job at a time.</source>
        <translation>同時に変換するジョブ数を設定します｡1に設定すると(既定)一度に一つ処理します｡</translation>
    </message>
    <message>
        <source>On DVD insertion</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do nothing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play DVD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rip DVD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Media Monitoring should be turned on to allow this feature (Setup -&gt; General -&gt; CD/DVD Monitor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display mythdvd menu</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ThemeUI</name>
    <message>
        <source>Rip/Transcode</source>
        <translation>リッピング/変換</translation>
    </message>
    <message>
        <source>Job 1 of 1</source>
        <translation>ジョブ 1/1</translation>
    </message>
    <message>
        <source>Length:</source>
        <translation>長さ:</translation>
    </message>
    <message>
        <source>Select:</source>
        <translation>選択:</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>名前:</translation>
    </message>
    <message>
        <source>Quality:</source>
        <translation>品質:</translation>
    </message>
    <message>
        <source>Audio Track:</source>
        <translation>オーディオトラック:</translation>
    </message>
    <message>
        <source>AC3 Audio:</source>
        <translation>AC3オーディオ:</translation>
    </message>
    <message>
        <source>Subtitles:</source>
        <translation>サブタイトル:</translation>
    </message>
    <message>
        <source>View:</source>
        <translation>ビュー:</translation>
    </message>
    <message>
        <source>Title 1 of 1</source>
        <translation>タイトル 1/1</translation>
    </message>
    <message>
        <source>0:00:00</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TitleDialog</name>
    <message>
        <source>Unkown</source>
        <translation>不明</translation>
    </message>
    <message>
        <source>%1 - Title %2</source>
        <translation>%1 - タイトル %2</translation>
    </message>
    <message>
        <source>Perfect</source>
        <translation>完璧</translation>
    </message>
    <message>
        <source>None</source>
        <translation>無し</translation>
    </message>
    <message>
        <source>Title %1 of %2</source>
        <translation>タイトル %1 of %2</translation>
    </message>
    <message>
        <source>0 Process Selected Title</source>
        <translation>0 プロセス、選択タイトル</translation>
    </message>
    <message>
        <source>0 Process Selected Titles</source>
        <translation>0 プロセス、選択タイトル</translation>
    </message>
</context>
</TS>
